| Title: | Access Global Building Height Datasets |
|---|---|
| Description: | Provides tools to access, search, and download global 3D building footprint datasets (3D-GloBFP) generated by Che et al. (2024) <doi:10.5194/essd-16-5357-2024>. The package includes functions to retrieve metadata, filter by bounding box, and download building height tiles. |
| Authors: | Xiaohao Yang [aut, cre, cph] |
| Maintainer: | Xiaohao Yang <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.4 |
| Built: | 2026-05-31 08:24:09 UTC |
| Source: | https://github.com/billbillbilly/globfpr |
Returns a spatial grid (as an sf object) containing metadata and download URLs for global 3D building footprint tiles (3D-GloBFP).
get_metadata(test = FALSE)get_metadata(test = FALSE)
test |
logic, Ignored during normal use; included for internal testing
purposes. Defaults to |
The metadata of 3D Global Building Footprints (3D-GloBFP) dataset is uploaded on zenodo. More detials about this dataset can to found here.
The data is detailed in the following article
sf a spatial polygon grid with attributes:
id, gridID, bounding box coordinates, and download_url.
Che, Y., Li, X., Liu, X., Wang, Y., Liao, W., Zheng, X., Zhang, X., Xu, X., Shi, Q., Zhu, J., Zhang, H., Yuan, H., & Dai, Y. (2025). 3D-GloBFP: the first global three-dimensional building footprint dataset. Zenodo. https://doi.org/10.5281/zenodo.15487037
Che Yangzi, Li Xuecao, Liu Xiaoping, Wang Yuhao, Liao Weilin, Zheng Xianwei, Zhang Xucai, Xu Xiaocong, Shi Qian, Zhu Jiajun, Zhang Honghui, Yuan Hua, & Dai Yongjiu (2024). 3D-GloBFP: the first global three-dimensional building footprint dataset. Earth Syst. Sci. Data, 16, 5357-5374
meta <- gloBFPr::get_metadata(test=TRUE)meta <- gloBFPr::get_metadata(test=TRUE)
Search and retrieve 3D-GloBFP tiles that intersect a given bounding box or area of interest, with options to return vector or raster outputs including building polygons, binary presence rasters, and height-coded rasters.
search_3dglobdf( bbox, metadata, crop = FALSE, out_type = "poly", mask = FALSE, cell_size = 1 )search_3dglobdf( bbox, metadata, crop = FALSE, out_type = "poly", mask = FALSE, cell_size = 1 )
bbox |
|
metadata |
sf. Typically output from |
crop |
logical. If |
out_type |
character. Default is
|
mask |
logical (optional). Default is |
cell_size |
numeric (optional). Default is 1. Only used when |
Varies based on out_type:
If "poly": an sf object of building footprints.
If "binary_rast": a binary SpatRaster (terra) indicating building presence.
If "graduated_rast": a quantitative SpatRaster of building heights.
If "rast": a named list with two SpatRaster objects: binary and graduated.
If "all": a named list with poly (sf), binary, and graduated rasters.
The downloading process may take some time, depending on the number and size of building footprint tiles.
This implementation relies on the current structure of the dataset as hosted on Figshare. It may break if the dataset owner changes the file organization or metadata format.
Che Yangzi, Li Xuecao, Liu Xiaoping, Wang Yuhao, Liao Weilin, Zheng Xianwei, Zhang Xucai, Xu Xiaocong, Shi Qian, Zhu Jiajun, Zhang Honghui, Yuan Hua, & Dai Yongjiu (2024). 3D-GloBFP: the first global three-dimensional building footprint dataset. Earth Syst. Sci. Data, 16, 5357-5374
metadata <- gloBFPr::get_metadata(test=TRUE) buildings <- gloBFPr::search_3dglobdf(bbox=c(-84.485519,45.636118,-84.462774,45.650639), metadata=metadata)metadata <- gloBFPr::get_metadata(test=TRUE) buildings <- gloBFPr::search_3dglobdf(bbox=c(-84.485519,45.636118,-84.462774,45.650639), metadata=metadata)